summaryrefslogtreecommitdiff
path: root/sc/source/ui/docshell/docsh2.cxx
diff options
context:
space:
mode:
authorMikhail Voytenko <mav@openoffice.org>2011-01-17 13:20:22 +0100
committerMikhail Voytenko <mav@openoffice.org>2011-01-17 13:20:22 +0100
commitcd42389ad67b403a07a0dda8e2a6e213def49251 (patch)
tree51e19c743788a549502b7c801c64e11142103310 /sc/source/ui/docshell/docsh2.cxx
parent3d6a5a98cda10e18dacd96028f2bf0ec0b478988 (diff)
removetooltypes01: #i112600# remove tooltypes from sc
Diffstat (limited to 'sc/source/ui/docshell/docsh2.cxx')
-rw-r--r--sc/source/ui/docshell/docsh2.cxx16
1 files changed, 8 insertions, 8 deletions
diff --git a/sc/source/ui/docshell/docsh2.cxx b/sc/source/ui/docshell/docsh2.cxx
index 14ff7622818c..084e35b610ba 100644
--- a/sc/source/ui/docshell/docsh2.cxx
+++ b/sc/source/ui/docshell/docsh2.cxx
@@ -72,22 +72,22 @@ using namespace com::sun::star;
//------------------------------------------------------------------
-BOOL __EXPORT ScDocShell::InitNew( const uno::Reference < embed::XStorage >& xStor )
+sal_Bool __EXPORT ScDocShell::InitNew( const uno::Reference < embed::XStorage >& xStor )
{
RTL_LOGFILE_CONTEXT_AUTHOR ( aLog, "sc", "nn93723", "ScDocShell::InitNew" );
- BOOL bRet = SfxObjectShell::InitNew( xStor );
+ sal_Bool bRet = SfxObjectShell::InitNew( xStor );
aDocument.MakeTable(0);
// zusaetzliche Tabellen werden von der ersten View angelegt,
// wenn bIsEmpty dann noch TRUE ist
if( bRet )
{
Size aSize( (long) ( STD_COL_WIDTH * HMM_PER_TWIPS * OLE_STD_CELLS_X ),
(long) ( ScGlobal::nStdRowHeight * HMM_PER_TWIPS * OLE_STD_CELLS_Y ) );
// hier muss auch der Start angepasst werden
- SetVisAreaOrSize( Rectangle( Point(), aSize ), TRUE );
+ SetVisAreaOrSize( Rectangle( Point(), aSize ), sal_True );
}
aDocument.SetDrawDefaults(); // drawing layer defaults that are set only in InitNew
@@ -129,13 +129,13 @@ BOOL __EXPORT ScDocShell::InitNew( const uno::Reference < embed::XStorage >& xSt
//------------------------------------------------------------------
-BOOL ScDocShell::IsEmpty() const
+sal_Bool ScDocShell::IsEmpty() const
{
return bIsEmpty;
}
-void ScDocShell::SetEmpty(BOOL bSet)
+void ScDocShell::SetEmpty(sal_Bool bSet)
{
bIsEmpty = bSet;
}
@@ -211,7 +211,7 @@ void ScDocShell::InitItems()
if ( !aDocument.IsValidAsianCompression() )
{
// set compression mode from configuration if not already set (e.g. XML import)
- aDocument.SetAsianCompression( sal::static_int_cast<BYTE>( aAsian.GetCharDistanceCompression() ) );
+ aDocument.SetAsianCompression( sal::static_int_cast<sal_uInt8>( aAsian.GetCharDistanceCompression() ) );
}
if ( !aDocument.IsValidAsianKerning() )
@@ -257,7 +257,7 @@ ScDrawLayer* ScDocShell::MakeDrawLayer()
InitItems(); // incl. Undo und Basic
Broadcast( SfxSimpleHint( SC_HINT_DRWLAYER_NEW ) );
if (nDocumentLock)
- pDrawLayer->setLock(TRUE);
+ pDrawLayer->setLock(sal_True);
}
return pDrawLayer;
}
@@ -72,22 +72,22 @@ using namespace com::sun::star;
aDocument.MakeTable(0);
// zusaetzliche Tabellen werden von der ersten View angelegt,
- // wenn bIsEmpty dann noch TRUE ist
+ // wenn bIsEmpty dann noch sal_True ist
if( bRet )
{